#!/usr/bin/env python3

"""
Example python application
"""
import os
import time
import csv
from datetime import datetime, timezone, timedelta


def log_temp():
    """
    Log date and temperature
    """
    data = {}

    jst = timezone(timedelta(hours=+9), 'JST')
    data['time'] = datetime.now(jst)

    thermal_prefix = '/sys/class/thermal/thermal_zone'
    with open(f'{thermal_prefix}0/temp', 'br') as f:
        data['cpu temperature'] = int(f.read()) / 1000

    # All armadillos don't have soc temp
    if os.path.exists(f'{thermal_prefix}1'):
        with open(f'{thermal_prefix}1/temp', 'br') as f:
            data['soc temperature'] = int(f.read()) / 1000

    add_header = False
    if not os.path.exists('/vol_data/log/temp.txt'):
        os.makedirs('/vol_data/log', exist_ok=True)
        add_header = True

    with open('/vol_data/log/temp.txt', 'a') as f:
        writer = csv.DictWriter(f, fieldnames=data.keys())
        if add_header:
            writer.writeheader()
        writer.writerow(data)


def blink():
    """
    Blink forever
    """
    # LED path depends on which armadillo is used,
    # try from list
    leds = ['app', 'led1', 'green']
    for led in leds:
        led = f'/sys/class/leds/{led}/brightness'
        if os.path.exists(led):
            break
    else:
        print("No led found, not blinking")
        return

    fd = os.open(led, os.O_RDWR)
    while True:
        os.pwrite(fd, b'0', 0)
        time.sleep(0.5)
        os.pwrite(fd, b'1', 0)
        time.sleep(0.5)


if __name__ == '__main__':
    log_temp()
    blink()
